/*
 * flipmapobjects.h
 * Copyright 2013, Thorbjørn Lindeijer <thorbjorn@lindeijer.nl>
 *
 * This file is part of Tiled.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FLIPMAPOBJECTS_H
#define FLIPMAPOBJECTS_H

#include "mapobject.h"

#include <QList>
#include <QUndoCommand>

namespace Tiled {
namespace Internal {

class MapDocument;

class FlipMapObjects : public QUndoCommand
{
public:
    FlipMapObjects(MapDocument *mapDocument,
                   const QList<MapObject *> &mapObjects,
                   FlipDirection flipDirection);

    void undo() override { flip(); }
    void redo() override { flip(); }

private:
    void flip();

    MapDocument *mMapDocument;
    QList<MapObject *> mMapObjects;
    FlipDirection mFlipDirection;
};

} // namespace Internal
} // namespace Tiled

#endif // FLIPMAPOBJECTS_H
